import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../../common/images.dart';
import '../../../common/theme/app_colors.dart';
import '../../../common/theme/app_text_style.dart';
import '../../../domain/models/present.dart';
import '../../controllers/quiz_notifier.dart';

class SelectPresentButton extends ConsumerStatefulWidget {
  const SelectPresentButton({
    super.key,
    required this.callback,
    required this.present,
  });

  final Function()? callback;
  final Present present;

  @override
  ConsumerState<SelectPresentButton> createState() =>
      _SelectPresentButtonState();
}

class _SelectPresentButtonState extends ConsumerState<SelectPresentButton> {
  bool isHovered = false;

  String get iconName {
    switch (widget.present) {
      case Present.avto:
        return AppIcons.avto;
      case Present.flat:
        return AppIcons.flat;
      case Present.moto:
        return AppIcons.moto;
      case Present.phone:
        return '';
    }
  }

  String get count {
    final quizState = ref.watch(quizNotifierProvider);
    switch (widget.present) {
      case Present.avto:
        return quizState.currentPresent == Present.avto
            ? (quizState.avtoRest - 1).toString()
            : quizState.avtoRest.toString();
      case Present.flat:
        return quizState.currentFlatNumber != null
            ? (ref.read(quizNotifierProvider.notifier).flatResrCount - 1)
                .toString()
            : ref.read(quizNotifierProvider.notifier).flatResrCount.toString();
      case Present.moto:
        return quizState.currentPresent == Present.moto
            ? (quizState.motoRest - 1).toString()
            : quizState.motoRest.toString();
      case Present.phone:
        return '';
    }
  }

  bool get isSelected {
    final quizState = ref.watch(quizNotifierProvider);
    if (widget.present == Present.avto &&
            quizState.currentPresent == Present.avto ||
        widget.present == Present.moto &&
            quizState.currentPresent == Present.moto ||
        widget.present == Present.flat &&
            quizState.currentPresent == Present.flat) {
      return true;
    }
    return false;
  }

  @override
  Widget build(BuildContext context) {
    final bool isDisalable = widget.callback == null;
    return Container(
      decoration: BoxDecoration(
        boxShadow: isDisalable || isSelected
            ? null
            : isHovered
                ? [
                    BoxShadow(
                      color: AppColors.seaDark.withOpacity(0.4),
                      blurRadius: 10,
                    )
                  ]
                : null,
        borderRadius: BorderRadius.circular(16.r),
        color: isSelected ? AppColors.white : null,
        border: Border.all(
            width: 1.h,
            color: isSelected
                ? AppColors.green
                : isDisalable
                    ? AppColors.blueSelectDisableBorder
                    : AppColors.blueSelectActiveBorder),
      ),
      child: ElevatedButton(
        onPressed: widget.callback,
        style: ButtonStyle(
          textStyle: MaterialStateProperty.all<TextStyle>(
            Sans().size36Weihtg600.copyWith(
                color: isSelected ? AppColors.green : AppColors.white),
          ),
          backgroundColor: MaterialStateProperty.all(Colors.transparent),
          shape: MaterialStateProperty.all<RoundedRectangleBorder>(
            RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(isSelected ? 15.r : 16.r),
            ),
          ),
          overlayColor: MaterialStateProperty.all<Color>(Colors.transparent),
          padding:
              MaterialStateProperty.all<EdgeInsetsGeometry>(EdgeInsets.zero),
          fixedSize: MaterialStateProperty.all<Size>(Size(198.w, 128.h)),
          elevation: MaterialStateProperty.all<double>(0),
        ),
        onHover: (value) {
          isHovered = value;
          setState(() {});
        },
        child: Container(
          padding: EdgeInsets.all(10.w),
          decoration: BoxDecoration(
            color: isSelected ? AppColors.white : null,
            gradient: isSelected
                ? null
                : const LinearGradient(
                    colors: [
                      AppColors.blueSelectGradientLight,
                      AppColors.blueSelectGradientDark
                    ],
                    begin: Alignment.topLeft,
                    end: Alignment.bottomRight,
                  ),
            borderRadius: BorderRadius.circular(14.r),
          ),
          height: 120.h,
          width: 190.w,
          child: Row(
            children: [
              Stack(
                clipBehavior: Clip.none,
                alignment: Alignment.center,
                children: [
                  if (isSelected)
                    Positioned(
                        left: -10.w,
                        top: 6.w,
                        child: SvgPicture.asset(
                          AppIcons.starFill,
                          width: 21.w,
                          height: 21.w,
                        )),
                  if (isSelected)
                    Positioned(
                        right: -6.w,
                        bottom: 1.w,
                        child: SvgPicture.asset(
                          AppIcons.star,
                          width: 19.w,
                          height: 19.w,
                        )),
                  Container(
                    padding: EdgeInsets.all(10.w),
                    width: 96.w,
                    height: 96.w,
                    decoration: BoxDecoration(
                      image: isSelected
                          ? const DecorationImage(
                              image: AssetImage(AppBackgrounds.pointsPng),
                              fit: BoxFit.fill)
                          : null,
                      shape: BoxShape.circle,
                      color: AppColors.white.withOpacity(isDisalable ? 0.4 : 1),
                      boxShadow: [
                        BoxShadow(
                            color: AppColors.white
                                .withOpacity(isDisalable ? 0.4 : 1),
                            blurRadius: 3.2.w)
                      ],
                    ),
                    child: SvgPicture.asset(
                      iconName,
                      fit: BoxFit.fill,
                    ),
                  ),
                ],
              ),
              Expanded(
                child: Text(
                  count,
                  style: Sans().size36Weihtg600.copyWith(
                      color: isSelected ? AppColors.green : AppColors.white),
                  textAlign: TextAlign.center,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
